@@ -1,5 +1,11 @@
+#
+# This file is part of pysnmp software.
+#
+# Copyright (c) 2005-2016, Ilya Etingof <ilya@glas.net>
+# License: http://pysnmp.sf.net/license.html
+#
 # Limited-size dictionary-like class to use for caches
-
+#
 class Cache:
     def __init__(self, maxSize=256):
         self.__maxSize = maxSize
@@ -13,7 +19,7 @@ class Cache:
         return k in self.__cache
 
     def __getitem__(self, k):
-        self.__usage[k] = self.__usage[k] + 1
+        self.__usage[k] += 1
         return self.__cache[k]
 
     def __len__(self):
@@ -28,7 +34,7 @@ class Cache:
                 del self.__usage[_k]
             self.__size = self.__size - self.__chopSize
         if k not in self.__cache:
-            self.__size = self.__size + 1
+            self.__size += 1
             self.__usage[k] = 0
         self.__cache[k] = v
 
