@@ -1,3 +1,9 @@
+#
+# This file is part of pysnmp software.
+#
+# Copyright (c) 2005-2016, Ilya Etingof <ilya@glas.net>
+# License: http://pysnmp.sf.net/license.html
+#
 import sys
 from pyasn1.compat.octets import null
 from pysnmp.entity.rfc3413 import config
@@ -264,9 +270,10 @@ class NotificationOriginator:
                        not self.__pendingNotifications[notificationHandle]:
                     if notificationHandle in self.__pendingNotifications:
                         del self.__pendingNotifications[notificationHandle]
-                    cbFun(snmpEngine, notificationHandle,
-                          statusInformation['errorIndication'], 0, 0, (),
-                          cbCtx)
+                    if cbFun:
+                        cbFun(snmpEngine, notificationHandle,
+                              statusInformation['errorIndication'], 0, 0, (),
+                              cbCtx)
                 return notificationHandle
 
             debug.logger & debug.flagApp and debug.logger('sendVarBinds: notificationHandle %s, sendRequestHandle %s, timeout %d' % (notificationHandle, sendRequestHandle, timeout))
