@@ -1,3 +1,10 @@
+#
+# This file is part of pysnmp software.
+#
+# Copyright (c) 2005-2016, Ilya Etingof <ilya@glas.net>
+# License: http://pysnmp.sf.net/license.html
+#
+from sys import version_info
 from pysnmp.hlapi.asyncore import cmdgen
 from pysnmp.hlapi.varbinds import *
 from pysnmp.proto.rfc1905 import endOfMibView
@@ -6,6 +13,12 @@ from pyasn1.type.univ import Null
 
 __all__ = ['getCmd', 'nextCmd', 'setCmd', 'bulkCmd']
 
+if version_info[:2] < (2, 6):
+    __all__.append('next')
+
+    def next(iter):
+        return iter.next()
+
 def getCmd(snmpEngine, authData, transportTarget, contextData,
            *varBinds, **options):
     """Creates a generator to perform one or more SNMP GET queries.
