@@ -1,4 +1,9 @@
-# SNMP v3 USM model services
+#
+# This file is part of pysnmp software.
+#
+# Copyright (c) 2005-2016, Ilya Etingof <ilya@glas.net>
+# License: http://pysnmp.sf.net/license.html
+#
 import time, sys
 from pysnmp.proto.secmod.base import AbstractSecurityModel
 from pysnmp.proto.secmod.rfc3414.auth import hmacmd5, hmacsha, noauth
@@ -17,7 +22,7 @@ from pyasn1.compat.octets import null
 
 class UsmSecurityParameters(rfc1155.TypeCoercionHackMixIn, univ.Sequence):
     componentType = namedtype.NamedTypes(
-        namedtype.NamedType('msgAuthoritativeEngineID', univ.OctetString()),
+        namedtype.NamedType('msgAuthoritativeEngineId', univ.OctetString()),
         namedtype.NamedType('msgAuthoritativeEngineBoots', univ.Integer().subtype(subtypeSpec=constraint.ValueRangeConstraint(0, 2147483647))),
         namedtype.NamedType('msgAuthoritativeEngineTime', univ.Integer().subtype(subtypeSpec=constraint.ValueRangeConstraint(0, 2147483647))),
         namedtype.NamedType('msgUserName', univ.OctetString().subtype(subtypeSpec=constraint.ValueSizeConstraint(0, 32))),
@@ -53,7 +58,7 @@ class SnmpUSMSecurityModel(AbstractSecurityModel):
 
             nextMibNode = usmUserEngineID
 
-            while 1:
+            while True:
                 try:
                     nextMibNode = usmUserEngineID.getNextNode(nextMibNode.name)
 
@@ -235,8 +240,8 @@ class SnmpUSMSecurityModel(AbstractSecurityModel):
 
             except NoSuchInstanceError:
                 pysnmpUsmDiscovery, = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols('__PYSNMP-USM-MIB', 'pysnmpUsmDiscovery')
-                __reportUnknownName = not pysnmpUsmDiscovery.syntax
-                if not __reportUnknownName:
+                reportUnknownName = not pysnmpUsmDiscovery.syntax
+                if not reportUnknownName:
                     try:
                         (usmUserName, usmUserSecurityName,
                          usmUserAuthProtocol, usmUserAuthKeyLocalized,
@@ -248,9 +253,9 @@ class SnmpUSMSecurityModel(AbstractSecurityModel):
                          )
 
                     except NoSuchInstanceError:
-                        __reportUnknownName = 1
+                        reportUnknownName = True
 
-                if __reportUnknownName:
+                if reportUnknownName:
                     raise error.StatusInformation(
                         errorIndication=errind.unknownSecurityName
                     )
@@ -258,9 +263,9 @@ class SnmpUSMSecurityModel(AbstractSecurityModel):
                 debug.logger & debug.flagSM and debug.logger('__generateRequestOrResponseMsg: clone user info')
 
             except PyAsn1Error:
-                debug.logger & debug.flagSM and debug.logger('processIncomingMsg: %s' % (sys.exc_info()[1],))
+                debug.logger & debug.flagSM and debug.logger('__generateRequestOrResponseMsg: %s' % (sys.exc_info()[1],))
                 snmpInGenErrs, = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols('__SNMPv2-MIB', 'snmpInGenErrs')
-                snmpInGenErrs.syntax = snmpInGenErrs.syntax + 1
+                snmpInGenErrs.syntax += 1
                 raise error.StatusInformation(
                     errorIndication=errind.invalidMsg
                 )
@@ -507,7 +512,7 @@ class SnmpUSMSecurityModel(AbstractSecurityModel):
             raise error.StatusInformation(errorIndication=errind.parseError)
 
         # 3.2.2
-        msgAuthoritativeEngineID = securityParameters.getComponentByPosition(0)
+        msgAuthoritativeEngineId = securityParameters.getComponentByPosition(0)
         securityStateReference = self._cache.push(
             msgUserName=securityParameters.getComponentByPosition(3)
         )
@@ -520,15 +525,21 @@ class SnmpUSMSecurityModel(AbstractSecurityModel):
         contextEngineId = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols('__SNMP-FRAMEWORK-MIB', 'snmpEngineID')[0].syntax
         contextName = null
 
+        snmpEngineID = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols('__SNMP-FRAMEWORK-MIB', 'snmpEngineID')[0].syntax
+
         # 3.2.3
-        if msgAuthoritativeEngineID not in self.__timeline:
-            debug.logger & debug.flagSM and debug.logger('processIncomingMsg: unknown securityEngineID %r' % (msgAuthoritativeEngineID,))
-            if not msgAuthoritativeEngineID or \
-                    not 4 < len(msgAuthoritativeEngineID) < 33:
+        if msgAuthoritativeEngineId != snmpEngineID and \
+                msgAuthoritativeEngineId not in self.__timeline:
+            if msgAuthoritativeEngineId and \
+                    4 < len(msgAuthoritativeEngineId) < 33:
+                # 3.2.3a - cloned user when request was sent
+                debug.logger & debug.flagSM and debug.logger('processIncomingMsg: unsynchronized securityEngineID %r' % (msgAuthoritativeEngineId,))
+            else:
                 # 3.2.3b
+                debug.logger & debug.flagSM and debug.logger('processIncomingMsg: peer requested snmpEngineID discovery')
                 usmStatsUnknownEngineIDs, = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols('__SNMP-USER-BASED-SM-MIB', 'usmStatsUnknownEngineIDs')
-                usmStatsUnknownEngineIDs.syntax = usmStatsUnknownEngineIDs.syntax+1
-                debug.logger & debug.flagSM and debug.logger('processIncomingMsg: null or malformed msgAuthoritativeEngineID')
+                usmStatsUnknownEngineIDs.syntax += 1
+                debug.logger & debug.flagSM and debug.logger('processIncomingMsg: null or malformed msgAuthoritativeEngineId')
                 pysnmpUsmDiscoverable, = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols('__PYSNMP-USM-MIB', 'pysnmpUsmDiscoverable')
                 if pysnmpUsmDiscoverable.syntax:
                     debug.logger & debug.flagSM and debug.logger('processIncomingMsg: starting snmpEngineID discovery procedure')
@@ -563,11 +574,9 @@ class SnmpUSMSecurityModel(AbstractSecurityModel):
                         errorIndication=errind.unknownEngineID
                     )
 
-        snmpEngineID = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols('__SNMP-FRAMEWORK-MIB', 'snmpEngineID')[0].syntax
-
         msgUserName = securityParameters.getComponentByPosition(3)
 
-        debug.logger & debug.flagSM and debug.logger('processIncomingMsg: read from securityParams msgAuthoritativeEngineID %r msgUserName %r' % (msgAuthoritativeEngineID, msgUserName))
+        debug.logger & debug.flagSM and debug.logger('processIncomingMsg: read from securityParams msgAuthoritativeEngineId %r msgUserName %r' % (msgAuthoritativeEngineId, msgUserName))
 
         if msgUserName:
             # 3.2.4
@@ -576,46 +585,29 @@ class SnmpUSMSecurityModel(AbstractSecurityModel):
                  usmUserAuthKeyLocalized, usmUserPrivProtocol,
                  usmUserPrivKeyLocalized) = self.__getUserInfo(
                      snmpEngine.msgAndPduDsp.mibInstrumController,
-                     msgAuthoritativeEngineID, msgUserName
+                     msgAuthoritativeEngineId, msgUserName
                  )
                 debug.logger & debug.flagSM and debug.logger('processIncomingMsg: read user info from LCD')
 
             except NoSuchInstanceError:
-                pysnmpUsmDiscoverable, = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols('__PYSNMP-USM-MIB', 'pysnmpUsmDiscoverable')
-                __reportUnknownName = not pysnmpUsmDiscoverable.syntax
-                if not __reportUnknownName:
-                    try:
-                        (usmUserName, usmUserSecurityName,
-                         usmUserAuthProtocol, usmUserAuthKeyLocalized,
-                         usmUserPrivProtocol,
-                         usmUserPrivKeyLocalized) = self.__cloneUserInfo(
-                             snmpEngine.msgAndPduDsp.mibInstrumController,
-                             msgAuthoritativeEngineID, msgUserName
-                         )
-                        debug.logger & debug.flagSM and debug.logger('processIncomingMsg: cloned user info')
-
-                    except NoSuchInstanceError:
-                        __reportUnknownName = 1
-
-                debug.logger & debug.flagSM and debug.logger('processIncomingMsg: unknown securityEngineID %r msgUserName %r' % (msgAuthoritativeEngineID, msgUserName))
-                if __reportUnknownName:
-                    usmStatsUnknownUserNames, = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols('__SNMP-USER-BASED-SM-MIB', 'usmStatsUnknownUserNames')
-                    usmStatsUnknownUserNames.syntax = usmStatsUnknownUserNames.syntax+1
-                    raise error.StatusInformation(
-                        errorIndication=errind.unknownSecurityName,
-                        oid=usmStatsUnknownUserNames.name,
-                        val=usmStatsUnknownUserNames.syntax,
-                        securityStateReference=securityStateReference,
-                        securityLevel=securityLevel,
-                        contextEngineId=contextEngineId,
-                        contextName=contextName,
-                        maxSizeResponseScopedPDU=maxSizeResponseScopedPDU
-                    )
+                debug.logger & debug.flagSM and debug.logger('processIncomingMsg: unknown securityEngineID %r msgUserName %r' % (msgAuthoritativeEngineId, msgUserName))
+                usmStatsUnknownUserNames, = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols('__SNMP-USER-BASED-SM-MIB', 'usmStatsUnknownUserNames')
+                usmStatsUnknownUserNames.syntax += 1
+                raise error.StatusInformation(
+                    errorIndication=errind.unknownSecurityName,
+                    oid=usmStatsUnknownUserNames.name,
+                    val=usmStatsUnknownUserNames.syntax,
+                    securityStateReference=securityStateReference,
+                    securityLevel=securityLevel,
+                    contextEngineId=contextEngineId,
+                    contextName=contextName,
+                    maxSizeResponseScopedPDU=maxSizeResponseScopedPDU
+                )
 
             except PyAsn1Error:
                 debug.logger & debug.flagSM and debug.logger('processIncomingMsg: %s' % (sys.exc_info()[1],))
                 snmpInGenErrs, = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols('__SNMPv2-MIB', 'snmpInGenErrs')
-                snmpInGenErrs.syntax = snmpInGenErrs.syntax + 1
+                snmpInGenErrs.syntax += 1
                 raise error.StatusInformation(errorIndication=errind.invalidMsg)
         else:
             # empty username used for engineID discovery
@@ -640,32 +632,48 @@ class SnmpUSMSecurityModel(AbstractSecurityModel):
         msgAuthoritativeEngineBoots = securityParameters.getComponentByPosition(1)
         msgAuthoritativeEngineTime = securityParameters.getComponentByPosition(2)
 
+        snmpEngine.observer.storeExecutionContext(
+            snmpEngine, 'rfc3414.processIncomingMsg',
+            dict(securityEngineId=msgAuthoritativeEngineId,
+                 snmpEngineBoots=msgAuthoritativeEngineBoots,
+                 snmpEngineTime=msgAuthoritativeEngineTime,
+                 userName=usmUserName,
+                 securityName=usmUserSecurityName,
+                 authProtocol=usmUserAuthProtocol,
+                 authKey=usmUserAuthKeyLocalized,
+                 privProtocol=usmUserPrivProtocol,
+                 privKey=usmUserPrivKeyLocalized)
+        )
+        snmpEngine.observer.clearExecutionContext(
+            snmpEngine, 'rfc3414.processIncomingMsg'
+        )
+            
         # 3.2.5
-        if msgAuthoritativeEngineID == snmpEngineID:
+        if msgAuthoritativeEngineId == snmpEngineID:
             # Authoritative SNMP engine: make sure securityLevel is sufficient
-            __badSecIndication = None
+            badSecIndication = None
             if securityLevel == 3:
                 if usmUserAuthProtocol == noauth.NoAuth.serviceID:
-                    __badSecIndication = 'authPriv wanted while auth not expected'
+                    badSecIndication = 'authPriv wanted while auth not expected'
                 if usmUserPrivProtocol == nopriv.NoPriv.serviceID:
-                    __badSecIndication = 'authPriv wanted while priv not expected'
+                    badSecIndication = 'authPriv wanted while priv not expected'
             elif securityLevel == 2:
                 if usmUserAuthProtocol == noauth.NoAuth.serviceID:
-                    __badSecIndication = 'authNoPriv wanted while auth not expected'
+                    badSecIndication = 'authNoPriv wanted while auth not expected'
                 if usmUserPrivProtocol != nopriv.NoPriv.serviceID:
                     # 4 (discovery phase always uses authenticated messages)
                     if msgAuthoritativeEngineBoots or msgAuthoritativeEngineTime:
-                        __badSecIndication = 'authNoPriv wanted while priv expected'
+                        badSecIndication = 'authNoPriv wanted while priv expected'
 
             elif securityLevel == 1:
                 if usmUserAuthProtocol != noauth.NoAuth.serviceID:
-                    __badSecIndication = 'noAuthNoPriv wanted while auth expected'
+                    badSecIndication = 'noAuthNoPriv wanted while auth expected'
                 if usmUserPrivProtocol != nopriv.NoPriv.serviceID:
-                    __badSecIndication = 'noAuthNoPriv wanted while priv expected'
-            if __badSecIndication:
+                    badSecIndication = 'noAuthNoPriv wanted while priv expected'
+            if badSecIndication:
                 usmStatsUnsupportedSecLevels, = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols('__SNMP-USER-BASED-SM-MIB', 'usmStatsUnsupportedSecLevels')
-                usmStatsUnsupportedSecLevels.syntax = usmStatsUnsupportedSecLevels.syntax + 1
-                debug.logger & debug.flagSM and debug.logger('processIncomingMsg: reporting inappropriate security level for user %s: %s' % (msgUserName, __badSecIndication))
+                usmStatsUnsupportedSecLevels.syntax += 1
+                debug.logger & debug.flagSM and debug.logger('processIncomingMsg: reporting inappropriate security level for user %s: %s' % (msgUserName, badSecIndication))
                 raise error.StatusInformation(
                     errorIndication=errind.unsupportedSecurityLevel,
                     oid=usmStatsUnsupportedSecLevels.name,
@@ -695,7 +703,7 @@ class SnmpUSMSecurityModel(AbstractSecurityModel):
 
             except error.StatusInformation:
                 usmStatsWrongDigests, = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols('__SNMP-USER-BASED-SM-MIB', 'usmStatsWrongDigests')
-                usmStatsWrongDigests.syntax = usmStatsWrongDigests.syntax+1
+                usmStatsWrongDigests.syntax += 1
                 raise error.StatusInformation(
                     errorIndication=errind.authenticationFailure,
                     oid=usmStatsWrongDigests.name,
@@ -709,25 +717,24 @@ class SnmpUSMSecurityModel(AbstractSecurityModel):
 
             debug.logger & debug.flagSM and debug.logger('processIncomingMsg: incoming msg authenticated')
 
-            if msgAuthoritativeEngineID:
-                # 3.2.3a moved down here to execute only for authed msg
-                self.__timeline[msgAuthoritativeEngineID] = (
-                    securityParameters.getComponentByPosition(1),
-                    securityParameters.getComponentByPosition(2),
-                    securityParameters.getComponentByPosition(2),
-                    int(time.time())
-                )
+            # synchronize time with authed peer
+            self.__timeline[msgAuthoritativeEngineId] = (
+                securityParameters.getComponentByPosition(1),
+                securityParameters.getComponentByPosition(2),
+                securityParameters.getComponentByPosition(2),
+                int(time.time())
+            )
 
-                expireAt = int(self.__expirationTimer + 300 / snmpEngine.transportDispatcher.getTimerResolution())
-                if expireAt not in self.__timelineExpQueue:
-                    self.__timelineExpQueue[expireAt] = []
-                self.__timelineExpQueue[expireAt].append(msgAuthoritativeEngineID)
+            expireAt = int(self.__expirationTimer + 300 / snmpEngine.transportDispatcher.getTimerResolution())
+            if expireAt not in self.__timelineExpQueue:
+                self.__timelineExpQueue[expireAt] = []
+            self.__timelineExpQueue[expireAt].append(msgAuthoritativeEngineId)
 
-                debug.logger & debug.flagSM and debug.logger('processIncomingMsg: store timeline for securityEngineID %r' % (msgAuthoritativeEngineID,))
+            debug.logger & debug.flagSM and debug.logger('processIncomingMsg: store timeline for securityEngineID %r' % (msgAuthoritativeEngineId,))
 
         # 3.2.7
         if securityLevel == 3 or securityLevel == 2:
-            if msgAuthoritativeEngineID == snmpEngineID:
+            if msgAuthoritativeEngineId == snmpEngineID:
                 # Authoritative SNMP engine: use local notion (SF bug #1649032)
                 (snmpEngineBoots, snmpEngineTime) = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols('__SNMP-FRAMEWORK-MIB', 'snmpEngineBoots', 'snmpEngineTime')
                 snmpEngineBoots = snmpEngineBoots.syntax
@@ -736,26 +743,26 @@ class SnmpUSMSecurityModel(AbstractSecurityModel):
                 debug.logger & debug.flagSM and debug.logger('processIncomingMsg: read snmpEngineBoots (%s), snmpEngineTime (%s) from LCD' % (snmpEngineBoots, snmpEngineTime))
             else:
                 # Non-authoritative SNMP engine: use cached estimates
-                if msgAuthoritativeEngineID in self.__timeline:
+                if msgAuthoritativeEngineId in self.__timeline:
                     (snmpEngineBoots, snmpEngineTime,
                      latestReceivedEngineTime,
                      latestUpdateTimestamp) = self.__timeline[
-                         msgAuthoritativeEngineID
+                         msgAuthoritativeEngineId
                      ]
                     # time passed since last talk with this SNMP engine
                     idleTime = int(time.time())-latestUpdateTimestamp
-                    debug.logger & debug.flagSM and debug.logger('processIncomingMsg: read timeline snmpEngineBoots %s snmpEngineTime %s for msgAuthoritativeEngineID %r, idle time %s secs' % (snmpEngineBoots, snmpEngineTime, msgAuthoritativeEngineID, idleTime))
+                    debug.logger & debug.flagSM and debug.logger('processIncomingMsg: read timeline snmpEngineBoots %s snmpEngineTime %s for msgAuthoritativeEngineId %r, idle time %s secs' % (snmpEngineBoots, snmpEngineTime, msgAuthoritativeEngineId, idleTime))
                 else:
                     raise error.ProtocolError('Peer SNMP engine info missing')
 
             # 3.2.7a
-            if msgAuthoritativeEngineID == snmpEngineID:
+            if msgAuthoritativeEngineId == snmpEngineID:
                 if snmpEngineBoots == 2147483647 or \
                    snmpEngineBoots != msgAuthoritativeEngineBoots or \
                    abs(idleTime + int(snmpEngineTime) - \
                        int(msgAuthoritativeEngineTime)) > 150:
                     usmStatsNotInTimeWindows, = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols('__SNMP-USER-BASED-SM-MIB', 'usmStatsNotInTimeWindows')
-                    usmStatsNotInTimeWindows.syntax = usmStatsNotInTimeWindows.syntax+1
+                    usmStatsNotInTimeWindows.syntax += 1
                     raise error.StatusInformation(
                         errorIndication=errind.notInTimeWindow,
                         oid=usmStatsNotInTimeWindows.name,
@@ -772,7 +779,7 @@ class SnmpUSMSecurityModel(AbstractSecurityModel):
                 if msgAuthoritativeEngineBoots > snmpEngineBoots or \
                        msgAuthoritativeEngineBoots == snmpEngineBoots and \
                        msgAuthoritativeEngineTime > latestReceivedEngineTime:
-                    self.__timeline[msgAuthoritativeEngineID] = (
+                    self.__timeline[msgAuthoritativeEngineId] = (
                         msgAuthoritativeEngineBoots,
                         msgAuthoritativeEngineTime,
                         msgAuthoritativeEngineTime,
@@ -781,9 +788,9 @@ class SnmpUSMSecurityModel(AbstractSecurityModel):
                     expireAt = int(self.__expirationTimer + 300 / snmpEngine.transportDispatcher.getTimerResolution())
                     if expireAt not in self.__timelineExpQueue:
                         self.__timelineExpQueue[expireAt] = []
-                    self.__timelineExpQueue[expireAt].append(msgAuthoritativeEngineID)
+                    self.__timelineExpQueue[expireAt].append(msgAuthoritativeEngineId)
 
-                    debug.logger & debug.flagSM and debug.logger('processIncomingMsg: stored timeline msgAuthoritativeEngineBoots %s msgAuthoritativeEngineTime %s for msgAuthoritativeEngineID %r' % (msgAuthoritativeEngineBoots, msgAuthoritativeEngineTime, msgAuthoritativeEngineID))
+                    debug.logger & debug.flagSM and debug.logger('processIncomingMsg: stored timeline msgAuthoritativeEngineBoots %s msgAuthoritativeEngineTime %s for msgAuthoritativeEngineId %r' % (msgAuthoritativeEngineBoots, msgAuthoritativeEngineTime, msgAuthoritativeEngineId))
 
                 # 3.2.7b.2
                 if snmpEngineBoots == 2147483647 or \
@@ -821,7 +828,7 @@ class SnmpUSMSecurityModel(AbstractSecurityModel):
 
             except error.StatusInformation:
                 usmStatsDecryptionErrors, = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols('__SNMP-USER-BASED-SM-MIB', 'usmStatsDecryptionErrors')
-                usmStatsDecryptionErrors.syntax = usmStatsDecryptionErrors.syntax+1
+                usmStatsDecryptionErrors.syntax += 1
                 raise error.StatusInformation(
                     errorIndication=errind.decryptionError,
                     oid=usmStatsDecryptionErrors.name,
@@ -863,15 +870,15 @@ class SnmpUSMSecurityModel(AbstractSecurityModel):
         debug.logger & debug.flagSM and debug.logger('processIncomingMsg: cached msgUserName %s info by securityStateReference %s' % (msgUserName, securityStateReference))
 
         # Delayed to include details
-        if not msgUserName and not msgAuthoritativeEngineID:
+        if not msgUserName and not msgAuthoritativeEngineId:
             usmStatsUnknownUserNames, = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols('__SNMP-USER-BASED-SM-MIB', 'usmStatsUnknownUserNames')
-            usmStatsUnknownUserNames.syntax = usmStatsUnknownUserNames.syntax+1
+            usmStatsUnknownUserNames.syntax += 1
             raise error.StatusInformation(
                 errorIndication=errind.unknownSecurityName,
                 oid=usmStatsUnknownUserNames.name,
                 val=usmStatsUnknownUserNames.syntax,
                 securityStateReference=securityStateReference,
-                securityEngineID=msgAuthoritativeEngineID,
+                securityEngineID=msgAuthoritativeEngineId,
                 securityLevel=securityLevel,
                 contextEngineId=contextEngineId,
                 contextName=contextName,
@@ -880,7 +887,7 @@ class SnmpUSMSecurityModel(AbstractSecurityModel):
             )
 
         # 3.2.12
-        return (msgAuthoritativeEngineID, securityName, scopedPDU,
+        return (msgAuthoritativeEngineId, securityName, scopedPDU,
                 maxSizeResponseScopedPDU, securityStateReference)
 
     def __expireTimelineInfo(self):
