@@ -13,6 +13,9 @@ wait for responses asynchronously:
 * with TRAP ID 'coldStart' specified as a MIB symbol
 * include managed object information specified as var-bind objects pair
 
+| $ snmptrap -v1 -c public demo.snmplabs.com 1.3.6.1.4.1.20408.4.1.1.2 195.218.195.228 6 432 12345 1.3.6.1.2.1.1.1.0 s "my system"
+| $ snmptrap -v2c -c public demo.snmplabs.com 123 1.3.6.1.6.3.1.1.5.1
+
 """#
 from pysnmp.hlapi.asyncore import *
 
@@ -21,11 +24,11 @@ from pysnmp.hlapi.asyncore import *
 targets = (
     # 1-st target (SNMPv1 over IPv4/UDP)
     ( CommunityData('public', mpModel=0),
-      UdpTransportTarget(('localhost', 162)),
+      UdpTransportTarget(('demo.snmplabs.com', 162)),
       ContextData() ),
     # 2-nd target (SNMPv2c over IPv4/UDP)
     ( CommunityData('public'),
-      UdpTransportTarget(('localhost', 162)),
+      UdpTransportTarget(('demo.snmplabs.com', 162)),
       ContextData() ),
 )
 
