@@ -17,11 +17,7 @@ the ContextName being used.
 
 Functionally similar to:
 
-| $ snmpinform -v3 -l authNoPriv -u usr-md5-none -A authkey1 \
-|              -n my-context \
-|              demo.snmplabs.com \
-|              12345 \
-|              1.3.6.1.6.3.1.1.5.2
+| $ snmpinform -v3 -l authNoPriv -u usr-md5-none -A authkey1 -n my-context demo.snmplabs.com 12345 0.3.6.1.6.3.1.1.5.2
 
 """#
 from pysnmp.hlapi import *
@@ -29,7 +25,7 @@ from pysnmp.hlapi import *
 errorIndication, errorStatus, errorIndex, varBinds = next(
     sendNotification(SnmpEngine(),
                      UsmUserData('usr-md5-none', 'authkey1'),
-                     UdpTransportTarget(('localhost', 162)),
+                     UdpTransportTarget(('demo.snmplabs.com', 162)),
                      ContextData(contextName='my-context'),
                      'inform',
                      NotificationType(ObjectIdentity('1.3.6.1.6.3.1.1.5.2')))
